@@ -185,14 +185,15 @@ char * linkage_print_senses(Linkage linkage)
 #ifdef USE_CORPUS
 	Linkage_info *lifo = linkage->info;
 	Sense *sns;
-	size_t w, nwords;
+	size_t nwords;
+	WordIdx w;
 
 	lg_corpus_linkage_senses(linkage);
 
-	nwords = lifo->nwords;
+	nwords = linkage->num_words;
 	for (w=0; w<nwords; w++)
 	{
-		sns = lg_get_word_sense(lifo, w);
+		sns = lg_get_word_sense(linkage, w);
 		while (sns)
 		{
 			int idx = lg_sense_get_index(sns);
@@ -691,7 +692,7 @@ char * linkage_print_postscript(const Linkage linkage, bool display_walls, bool
 	size = strlen(header(print_ps_header)) + strlen(ps) + strlen(trailer(print_ps_header)) + 1;
 
 	qs = (char *) exalloc(sizeof(char)*size);
-	sprintf(qs, "%s%s%s", header(print_ps_header), ps, trailer(print_ps_header));
+	snprintf(qs, size, "%s%s%s", header(print_ps_header), ps, trailer(print_ps_header));
 	exfree(ps, strlen(ps)+1);
 
 	return qs;
