@@ -16,6 +16,7 @@
 
 #include <math.h>
 #include <stdio.h>
+#include <stdint.h>
 
 #include "count.h"
 #include "dict-api.h"
@@ -133,7 +134,7 @@ static int exp_contains(Exp * super, Exp * sub)
 {
 	E_list * el;
 
-#ifdef DEBUG
+#if 0 /* DEBUG */
 	printf("SUP: ");
 	if (super) print_expression(super);
 	printf("\n");
@@ -203,26 +204,12 @@ void free_connectors(Connector *e)
 	}
 }
 
-void exfree_connectors(Connector *e)
-{
-	Connector * n;
-	for(;e != NULL; e = n) {
-		n = e->next;
-		exfree((void *) e->string, sizeof(char)*(strlen(e->string)+1));
-		xfree(e, sizeof(Connector)); /* even in this case, connector came from xalloc */
-	}
-}
-
 Connector * connector_new(void)
 {
 	Connector *c = (Connector *) xalloc(sizeof(Connector));
 	c->length_limit = UNLIMITED_LEN;
 	c->string = "";
 	c->hash = -1;
-#ifdef USE_FAT_LINKAGES
-	c->label = NORMAL_LABEL;
-	c->priority = THIN_priority;
-#endif /* USE_FAT_LINKAGES */
 	c->multi = false;
 	c->next = NULL;
 	c->tableNext = NULL;
@@ -236,67 +223,6 @@ Connector * init_connector(Connector *c)
 	return c;
 }
 
-/**
- * This builds a new copy of the connector list pointed to by c.
- * Strings, as usual, are not copied.
- */
-Connector * copy_connectors(Connector * c)
-{
-	Connector *c1;
-	if (c == NULL) return NULL;
-	c1 = connector_new();
-	*c1 = *c;
-	c1->next = copy_connectors(c->next);
-	return c1;
-}
-
-Connector * excopy_connectors(Connector * c)
-{
-	char * s;
-	Connector *c1;
-
-	if (c == NULL) return NULL;
-
-	c1 = connector_new();
-	*c1 = *c;
-	s = (char *) exalloc(sizeof(char)*(strlen(c->string)+1));
-	strcpy(s, c->string);
-	c1->string = s;
-	c1->next = excopy_connectors(c->next);
-
-	return c1;
-}
-
-/* ======================================================== */
-/* Link utilities ... */
-
-Link * excopy_link(Link * l)
-{
-	char * s;
-	Link * newl;
-
-	if (l == NULL) return NULL;
-
-	newl = (Link *) exalloc(sizeof(Link));
-	s = (char *) exalloc(sizeof(char)*(strlen(l->link_name)+1));
-	strcpy(s, l->link_name);
-	newl->link_name = s;
-	newl->lw = l->lw;
-	newl->rw = l->rw;
-	newl->lc = excopy_connectors(l->lc);
-	newl->rc = excopy_connectors(l->rc);
-
-	return newl;
-}
-
-void exfree_link(Link * l)
-{
-	exfree_connectors(l->rc);
-	exfree_connectors(l->lc);
-	exfree((void *)l->link_name, sizeof(char)*(strlen(l->link_name)+1));
-	exfree(l, sizeof(Link));
-}
-
 /* ======================================================== */
 /* Connector-set utilities ... */
 /**
@@ -367,20 +293,6 @@ void connector_set_delete(Connector_set * conset)
  * d='+' means this connector is on the right side of the disjunct.
  * d='-' means this connector is on the left side of the disjunct.
  */
-#ifdef USE_FAT_LINKAGES
-bool match_in_connector_set(count_context_t * ctxt, Connector_set *conset, Connector * c, int d)
-{
-	unsigned int h;
-	Connector * c1;
-	if (conset == NULL) return false;
-	h = connector_set_hash(conset, c->string, d);
-	for (c1 = conset->hash_table[h]; c1 != NULL; c1 = c1->next)
-	{
-		if (do_match(ctxt, c1, c, 0, 0) && (d == c1->word)) return true;
-	}
-	return false;
-}
-#else /* USE_FAT_LINKAGES */
 
 bool match_in_connector_set(Connector_set *conset, Connector * c, int dir)
 {
@@ -394,7 +306,6 @@ bool match_in_connector_set(Connector_set *conset, Connector * c, int dir)
 	}
 	return false;
 }
-#endif /* not USE_FAT_LINKAGES */
 
 /* ======================================================== */
 /* More connector utilities ... */
@@ -483,7 +394,7 @@ static bool dn_word_contains(Dictionary dict,
 
 	m_exp = m_dn->exp;
 
-#ifdef DEBUG
+#if 0 /* DEBUG */
 	printf("\nWORD: ");
 	print_expression(w_dn->exp);
 	printf("\nMACR: ");
@@ -538,9 +449,6 @@ int calculate_connector_hash(Connector * c)
 #ifdef USE_DJB2
 	/* djb2 hash */
 	i = 5381;
-#ifdef USE_FAT_LINKAGES
-	i = ((i << 5) + i) + (0xff & c->label);
-#endif /* USE_FAT_LINKAGES */
 	s = c->string;
 	if (islower((int) *s)) s++; /* ignore head-dependent indicator */
 	while (isupper((int) *s)) /* connector tables cannot contain UTF8, yet */
@@ -571,11 +479,7 @@ int calculate_connector_hash(Connector * c)
 
 #ifdef USE_SDBM
 	/* sdbm hash */
-#ifdef USE_FAT_LINKAGES
-	i = (0xff & c->label);
-#else
 	i = 0;
-#endif /* USE_FAT_LINKAGES */
 	s = c->string;
 	if (islower((int) *s)) s++; /* ignore head-dependent indicator */
 	while (isupper((int) *s))
